@@ -82,6 +82,10 @@ class Note {
 		return $this->noteUtil->getTagService()->isFavorite($this->getId());
 	}
 
+	public function getReadOnly() : bool {
+		return !$this->file->isUpdateable();
+	}
+
 
 	public function getData(array $exclude = []) : array {
 		$data = [];
@@ -100,8 +104,11 @@ class Note {
 		if (!in_array('favorite', $exclude)) {
 			$data['favorite'] = $this->getFavorite();
 		}
+		if (!in_array('readonly', $exclude)) {
+			$data['readonly'] = $this->getReadOnly();
+		}
 		$data['error'] = false;
-		$data['errorMessage'] = '';
+		$data['errorType'] = '';
 		if (!in_array('content', $exclude)) {
 			try {
 				$data['content'] = $this->getContent();
@@ -110,10 +117,11 @@ class Note {
 					'Could not read content for file: '.$this->file->getPath(),
 					[ 'exception' => $e ]
 				);
-				$message = $this->util->l10n->t('Error').': ('.$this->file->getName().') '.$e->getMessage();
+				$message = $this->util->l10n->t('Error').': '.get_class($e);
 				$data['content'] = $message;
 				$data['error'] = true;
-				$data['errorMessage'] = $message;
+				$data['errorType'] = get_class($e);
+				$data['readonly'] = true;
 			}
 		}
 		return $data;
@@ -125,10 +133,12 @@ class Note {
 
 
 	public function setTitle(string $title) : void {
+		$this->noteUtil->ensureNoteIsWritable($this->file);
 		$this->setTitleCategory($title);
 	}
 
 	public function setCategory(string $category) : void {
+		$this->noteUtil->ensureNoteIsWritable($this->file);
 		$this->setTitleCategory($this->getTitle(), $category);
 	}
 
@@ -136,6 +146,7 @@ class Note {
 	 * @throws \OCP\Files\NotPermittedException
 	 */
 	public function setTitleCategory(string $title, ?string $category = null) : void {
+		$this->noteUtil->ensureNoteIsWritable($this->file);
 		if ($category === null) {
 			$category = $this->getCategory();
 		}
@@ -155,11 +166,13 @@ class Note {
 	}
 
 	public function setContent(string $content) : void {
+		$this->noteUtil->ensureNoteIsWritable($this->file);
 		$this->noteUtil->ensureSufficientStorage($this->file->getParent(), strlen($content));
 		$this->file->putContent($content);
 	}
 
 	public function setModified(int $modified) : void {
+		$this->noteUtil->ensureNoteIsWritable($this->file);
 		$this->file->touch($modified);
 	}
 
